@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-01'; # DATE
 our $DIST = 'Acme-CPANModulesBundle-PERLANCAR'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our $LIST = {
     summary => 'List of my retired modules',
@@ -62,10 +62,10 @@ _
             module => 'Module::List::WithPath',
             description => <<'_',
 
-Superseded by <pm:PERLANCAR::Module::List>.
+Superseded by <pm:Module::List::More>.
 
 _
-            alternate_modules => ['PERLANCAR::Module::List'],
+            alternate_modules => ['Module::List::More'],
         },
         {
             module => 'App::CreateSparseFile',
@@ -116,7 +116,7 @@ Acme::CPANModules::PERLANCAR::MyRetired - List of my retired modules
 
 =head1 VERSION
 
-This document describes version 0.013 of Acme::CPANModules::PERLANCAR::MyRetired (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2023-11-01.
+This document describes version 0.014 of Acme::CPANModules::PERLANCAR::MyRetired (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2023-11-01.
 
 =head1 DESCRIPTION
 
@@ -166,10 +166,10 @@ Alternate modules: L<Unix::Passwd::File>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-Superseded by L<PERLANCAR::Module::List>.
+Superseded by L<Module::List::More>.
 
 
-Alternate modules: L<PERLANCAR::Module::List>
+Alternate modules: L<Module::List::More>
 
 =item L<App::CreateSparseFile>
 
